==> mobot-0.1.0-py3-none-any.whl: mobot/_tests/flashlight_test.py <==
# MIT License
#
# Copyright (c) 2021 Mobotx
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

import threading
from mobot.brain.agent import Agent

class FlashlightTestAgent(Agent):
    def __init__(self):
        Agent.__init__(self)
        self.flashlight.enable()
        self.control_thread = threading.Thread(target=self.control_thread)

    def on_start(self):
        self.control_thread.start()

    def control_thread(self):
        self.flashlight.turn_on()

def main():
    flashlight_test_agent = FlashlightTestAgent()
    flashlight_test_agent.start()

if __name__ == "__main__":
    main()

==> mobot-0.1.2-py3-none-any.whl: mobot/_tests/flashlight_test.py <==
# MIT License
#
# Copyright (c) 2021 Mobotx
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

import threading

from mobot.brain.agent import Agent


class FlashlightTestAgent(Agent):

    def __init__(self):
        super().__init__()
        self.flashlight.enable()
        self.control_thread = threading.Thread(
            target=self.control_thread
        )

    def on_start(self):
        self.control_thread.start()

    def control_thread(self):
        self.flashlight.turn_on()


def main():
    flashlight_test_agent = FlashlightTestAgent()
    flashlight_test_agent.start()


if __name__ == "__main__":
    main()
